
#ifndef _C1_ut22_
#define _C1_ut22_

#ifdef __cplusplus
extern "C" {
#endif

extern void F26_294(EIF_REFERENCE);
extern EIF_BOOLEAN F26_296(EIF_REFERENCE);
extern void F26_299(EIF_REFERENCE);
extern void F26_300(EIF_REFERENCE);
extern void EIF_Minit22(void);

#ifdef __cplusplus
}
#endif

#endif
